@@ -2,7 +2,7 @@
 
   hpmud.cpp - multi-point transport driver
  
-  (c) 2004-2007 Copyright Hewlett-Packard Development Company, LP
+  (c) 2004-2007 Copyright HP Development Company, LP
 
   Permission is hereby granted, free of charge, to any person obtaining a copy 
   of this software and associated documentation files (the "Software"), to deal 
@@ -97,7 +97,9 @@ int __attribute__ ((visibility ("hidden"))) is_hp(const char *id)
       return 0;
 
    if ((strncasecmp(pMf, "HEWLETT-PACKARD", 15) == 0) ||
-      (strncasecmp(pMf, "APOLLO", 6) == 0) || (strncasecmp(pMf, "HP", 2) == 0))
+      (strncasecmp(pMf, "APOLLO", 6) == 0) || 
+      (strncasecmp(pMf, "HP", 2) == 0) ||
+      (strncasecmp(pMf, "DEX", 3) == 0))
    {
       return 1;  /* found HP product */
    }
@@ -158,7 +160,15 @@ int __attribute__ ((visibility ("hidden"))) generalize_serial(const char *sz, ch
    for (i--; buf[i] == ' ' && i > 0; i--);  /* eat trailing white space */
 
    buf[++i] = 0;
-
+   /*sanitize the serial number. RFC-3986 Valid Serial number character set: [A-Za-z0-9_-]*/
+   for (i=0; i < bufSize && buf[i]; i++) 
+   {
+      if ( !(isalnum(buf[i]) || buf[i] == '-' || buf[i] == '_' ) ) 
+      {
+         DBG("Found invalid character %s in device serial number \n",buf[i]);
+         buf[i] = '\0';
+      }
+   }
    return i;   /* length does not include zero termination */
 }
 
@@ -226,9 +236,20 @@ enum HPMUD_RESULT __attribute__ ((visibility ("hidden"))) service_to_channel(mud
       *index = HPMUD_LEDM_SCAN_CHANNEL;
    }
    else if (strncasecmp(sn, "hp-marvell-ews", 11) == 0)
-     {
+   {
        *index = HPMUD_MARVELL_EWS_CHANNEL;
-     }
+   }
+   else if (strncasecmp(sn, "hp-ipp", 6) == 0)
+   {
+       if (strncasecmp(sn, "hp-ipp2", 7) == 0)
+            *index = HPMUD_IPP_CHANNEL2;
+       else
+            *index = HPMUD_IPP_CHANNEL;
+   }
+   else if (strncasecmp(sn, "hp-escl-scan", 12) == 0)
+   {
+      *index = HPMUD_ESCL_SCAN_CHANNEL;
+   }
    /* All the following services require MLC/1284.4. */
    else if (pd->io_mode == HPMUD_RAW_MODE || pd->io_mode == HPMUD_UNI_MODE)
    {
@@ -494,11 +515,11 @@ int hpmud_get_uri_datalink(const char *uri, char *buf, int buf_size)
 
    if (zc)
    {
-#ifdef HAVE_LIBNETSNMP
-      if (hpmud_mdns_lookup(p, HPMUD_MDNS_TIMEOUT, ip) != HPMUD_R_OK)
-	 return 0;
-      for (i=0; (ip[i] != 0) && (i < buf_size); i++)
-         buf[i] = ip[i];
+#ifdef HAVE_LIBAVAHI
+    if (avahi_lookup(p) != AVAHI_STATUS_OK)
+        return 0;
+    for (i=0; (ipAddressBuff[i] != 0) && (i < buf_size); i++)
+        buf[i] = ipAddressBuff[i];
 #else
       return 0;
 #endif
@@ -615,7 +636,7 @@ enum HPMUD_RESULT hpmud_probe_devices(enum HPMUD_BUS_ID bus, char *buf, int buf_
 
    if (bus == HPMUD_BUS_USB)
    {
-      len = musb_probe_devices(buf, buf_size, cnt);
+      len = musb_probe_devices(buf, buf_size, cnt, HPMUD_AIO);
    }
 #ifdef HAVE_PPORT
    else if (bus == HPMUD_BUS_PARALLEL)
@@ -625,7 +646,32 @@ enum HPMUD_RESULT hpmud_probe_devices(enum HPMUD_BUS_ID bus, char *buf, int buf_
 #endif
    else if (bus == HPMUD_BUS_ALL)
    {
-      len = musb_probe_devices(buf, buf_size, cnt);
+      len = musb_probe_devices(buf, buf_size, cnt, HPMUD_AIO);
+#ifdef HAVE_PPORT
+      len += pp_probe_devices(buf+len, buf_size-len, cnt);
+#endif
+   }
+
+   *bytes_read = len;
+
+   return HPMUD_R_OK;
+}
+
+enum HPMUD_RESULT hpmud_probe_printers(enum HPMUD_BUS_ID bus, char *buf, int buf_size, int *cnt, int *bytes_read)
+{
+   int len=0;
+
+   DBG("[%d] hpmud_probe_printers() bus=%d\n", getpid(), bus);
+
+   if (buf == NULL || buf_size <= 0)
+        return HPMUD_R_INVALID_LENGTH;
+    
+   buf[0] = 0;
+   *cnt = 0;
+
+   if (bus == HPMUD_BUS_ALL)
+   {
+      len = musb_probe_devices(buf, buf_size, cnt, HPMUD_PRINTER);
 #ifdef HAVE_PPORT
       len += pp_probe_devices(buf+len, buf_size-len, cnt);
 #endif
@@ -676,7 +722,7 @@ bugout:
 enum HPMUD_RESULT hpmud_write_channel(HPMUD_DEVICE dd, HPMUD_CHANNEL cd, const void *buf, int size, int sec_timeout, int *bytes_wrote)
 {
    enum HPMUD_RESULT stat = HPMUD_R_INVALID_STATE;
-
+   sec_timeout = 10; //hplip-1608, http write timeout issue for GEMS 2.0 
    DBG("[%d] hpmud_channel_write() dd=%d cd=%d buf=%p size=%d sectime=%d\n", getpid(), dd, cd, buf, size, sec_timeout);
 
    if (dd <= 0 || dd > HPMUD_DEVICE_MAX || msp->device[dd].index != dd ||
